@@ -3,7 +3,7 @@
 # VulnerableCode is a trademark of nexB Inc.
 # SPDX-License-Identifier: Apache-2.0
 # See http://www.apache.org/licenses/LICENSE-2.0 for the license text.
-# See https://github.com/nexB/vulnerablecode for support or download.
+# See https://github.com/aboutcode-org/vulnerablecode for support or download.
 # See https://aboutcode.org for more information about nexB OSS projects.
 #
 
@@ -48,7 +48,22 @@ class ApiUserCreationForm(forms.ModelForm):
 
     def __init__(self, *args, **kwargs):
         super(ApiUserCreationForm, self).__init__(*args, **kwargs)
-        self.fields["email"].required = True
+        email_field = self.fields["email"]
+        first_name_field = self.fields["first_name"]
+        last_name_field = self.fields["last_name"]
+        email_field.required = True
+        email_field.label = "Email"
+        email_field.widget.attrs["class"] = "input"
+        email_field.widget.attrs["style"] = "width: 50%"
+        email_field.widget.attrs["placeholder"] = "foo@bar.com"
+        first_name_field.label = "First Name"
+        first_name_field.widget.attrs["class"] = "input"
+        first_name_field.widget.attrs["style"] = "width: 50%"
+        first_name_field.widget.attrs["placeholder"] = "Jon"
+        last_name_field.label = "Last Name"
+        last_name_field.widget.attrs["class"] = "input"
+        last_name_field.widget.attrs["style"] = "width: 50%"
+        last_name_field.widget.attrs["placeholder"] = "Doe"
 
     def save(self, commit=True):
         return ApiUser.objects.create_api_user(
