@@ -3,7 +3,7 @@
 # VulnerableCode is a trademark of nexB Inc.
 # SPDX-License-Identifier: Apache-2.0
 # See http://www.apache.org/licenses/LICENSE-2.0 for the license text.
-# See https://github.com/nexB/vulnerablecode for support or download.
+# See https://github.com/aboutcode-org/vulnerablecode for support or download.
 # See https://aboutcode.org for more information about nexB OSS projects.
 #
 
@@ -24,6 +24,7 @@ from typing import Tuple
 
 import pytz
 from dateutil import parser as dateparser
+from fetchcode.vcs import VCSResponse
 from fetchcode.vcs import fetch_via_vcs
 from license_expression import Licensing
 from packageurl import PackageURL
@@ -36,10 +37,11 @@ from vulnerabilities.oval_parser import OvalParser
 from vulnerabilities.severity_systems import SCORING_SYSTEMS
 from vulnerabilities.severity_systems import ScoringSystem
 from vulnerabilities.utils import classproperty
-from vulnerabilities.utils import evolve_purl
 from vulnerabilities.utils import get_reference_id
 from vulnerabilities.utils import is_cve
 from vulnerabilities.utils import nearest_patched_package
+from vulnerabilities.utils import purl_to_dict
+from vulnerabilities.utils import update_purl_version
 
 logger = logging.getLogger(__name__)
 
@@ -50,12 +52,17 @@ class VulnerabilitySeverity:
     system: ScoringSystem
     value: str
     scoring_elements: str = ""
+    published_at: Optional[datetime.datetime] = None
 
     def to_dict(self):
+        published_at_dict = (
+            {"published_at": self.published_at.isoformat()} if self.published_at else {}
+        )
         return {
             "system": self.system.identifier,
             "value": self.value,
             "scoring_elements": self.scoring_elements,
+            **published_at_dict,
         }
 
     @classmethod
@@ -68,13 +75,14 @@ class VulnerabilitySeverity:
             system=SCORING_SYSTEMS[severity["system"]],
             value=severity["value"],
             scoring_elements=severity.get("scoring_elements", ""),
+            published_at=severity.get("published_at"),
         )
 
 
 @dataclasses.dataclass(order=True)
 class Reference:
-
     reference_id: str = ""
+    reference_type: str = ""
     url: str = ""
     severities: List[VulnerabilitySeverity] = dataclasses.field(default_factory=list)
 
@@ -84,11 +92,17 @@ class Reference:
 
     def normalized(self):
         severities = sorted(self.severities)
-        return Reference(reference_id=self.reference_id, url=self.url, severities=severities)
+        return Reference(
+            reference_id=self.reference_id,
+            url=self.url,
+            severities=severities,
+            reference_type=self.reference_type,
+        )
 
     def to_dict(self):
         return {
             "reference_id": self.reference_id,
+            "reference_type": self.reference_type,
             "url": self.url,
             "severities": [severity.to_dict() for severity in self.severities],
         }
@@ -97,6 +111,7 @@ class Reference:
     def from_dict(cls, ref: dict):
         return cls(
             reference_id=ref["reference_id"],
+            reference_type=ref["reference_type"],
             url=ref["url"],
             severities=[
                 VulnerabilitySeverity.from_dict(severity) for severity in ref["severities"]
@@ -153,8 +168,7 @@ class AffectedPackage:
         """
         if not self.fixed_version:
             raise ValueError(f"Affected Package {self.package!r} does not have a fixed version")
-        fixed_purl = evolve_purl(purl=self.package, version=str(self.fixed_version))
-        return fixed_purl
+        return update_purl_version(purl=self.package, version=str(self.fixed_version))
 
     @classmethod
     def merge(
@@ -187,7 +201,7 @@ class AffectedPackage:
             purls.add(pkg.package)
         if len(purls) > 1:
             raise UnMergeablePackageError("Cannot merge with different purls", purls)
-        return purls.pop(), sorted(affected_version_ranges), sorted(fixed_versions)
+        return purls.pop(), list(affected_version_ranges), sorted(fixed_versions)
 
     def to_dict(self):
         """
@@ -197,7 +211,7 @@ class AffectedPackage:
         if self.affected_version_range:
             affected_version_range = str(self.affected_version_range)
         return {
-            "package": self.package.to_dict(),
+            "package": purl_to_dict(self.package),
             "affected_version_range": affected_version_range,
             "fixed_version": str(self.fixed_version) if self.fixed_version else None,
         }
@@ -209,18 +223,30 @@ class AffectedPackage:
         """
         package = PackageURL(**affected_pkg["package"])
         affected_version_range = None
-        if (
-            affected_pkg["affected_version_range"]
-            and affected_pkg["affected_version_range"] != "None"
-        ):
-            affected_version_range = VersionRange.from_string(
-                affected_pkg["affected_version_range"]
-            )
+        affected_range = affected_pkg["affected_version_range"]
+
+        # TODO: "None" is a likely bug
+        if affected_range and affected_range != "None":
+            try:
+                affected_version_range = VersionRange.from_string(affected_range)
+            except:
+                tb = traceback.format_exc()
+                logger.error(
+                    f"Cannot create AffectedPackage with invalid or unknown range: {affected_pkg!r} with error: {tb!r}"
+                )
+                return
+
         fixed_version = affected_pkg["fixed_version"]
         if fixed_version and affected_version_range:
             # TODO: revisit after https://github.com/nexB/univers/issues/10
             fixed_version = affected_version_range.version_class(fixed_version)
 
+        if not fixed_version and not affected_version_range:
+            logger.error(
+                f"Cannot create AffectedPackage without fixed version or affected range: {affected_pkg!r}"
+            )
+            return
+
         return cls(
             package=package,
             affected_version_range=affected_version_range,
@@ -246,10 +272,22 @@ class AdvisoryData:
     affected_packages: List[AffectedPackage] = dataclasses.field(default_factory=list)
     references: List[Reference] = dataclasses.field(default_factory=list)
     date_published: Optional[datetime.datetime] = None
+    weaknesses: List[int] = dataclasses.field(default_factory=list)
+    url: Optional[str] = None
 
     def __post_init__(self):
         if self.date_published and not self.date_published.tzinfo:
             logger.warning(f"AdvisoryData with no tzinfo: {self!r}")
+        if self.summary:
+            self.summary = self.clean_summary(self.summary)
+
+    def clean_summary(self, summary):
+        # https://nvd.nist.gov/vuln/detail/CVE-2013-4314
+        # https://github.com/cms-dev/cms/issues/888#issuecomment-516977572
+        summary = summary.strip()
+        if summary:
+            summary = summary.replace("\x00", "\uFFFD")
+        return summary
 
     def to_dict(self):
         return {
@@ -258,6 +296,8 @@ class AdvisoryData:
             "affected_packages": [pkg.to_dict() for pkg in self.affected_packages],
             "references": [ref.to_dict() for ref in self.references],
             "date_published": self.date_published.isoformat() if self.date_published else None,
+            "weaknesses": self.weaknesses,
+            "url": self.url if self.url else "",
         }
 
     @classmethod
@@ -267,12 +307,16 @@ class AdvisoryData:
             "aliases": advisory_data["aliases"],
             "summary": advisory_data["summary"],
             "affected_packages": [
-                AffectedPackage.from_dict(pkg) for pkg in advisory_data["affected_packages"]
+                AffectedPackage.from_dict(pkg)
+                for pkg in advisory_data["affected_packages"]
+                if pkg is not None
             ],
             "references": [Reference.from_dict(ref) for ref in advisory_data["references"]],
             "date_published": datetime.datetime.fromisoformat(date_published)
             if date_published
             else None,
+            "weaknesses": advisory_data["weaknesses"],
+            "url": advisory_data.get("url") or None,
         }
         return cls(**transformed)
 
@@ -285,6 +329,10 @@ class InvalidSPDXLicense(Exception):
     pass
 
 
+class ForkError(Exception):
+    pass
+
+
 class Importer:
     """
     An Importer collects data from various upstreams and returns corresponding AdvisoryData objects
@@ -294,7 +342,9 @@ class Importer:
     spdx_license_expression = ""
     license_url = ""
     notice = ""
-    vcs_response = None
+    vcs_response: VCSResponse = None
+    # It needs to be unique and immutable
+    importer_name = ""
 
     def __init__(self):
         if not self.spdx_license_expression:
@@ -321,47 +371,18 @@ class Importer:
         raise NotImplementedError
 
     def clone(self, repo_url):
+        """
+        Clone the repo at repo_url and return the VCSResponse object
+        """
         try:
             self.vcs_response = fetch_via_vcs(repo_url)
+            return self.vcs_response
         except Exception as e:
             msg = f"Failed to fetch {repo_url} via vcs: {e}"
             logger.error(msg)
             raise ForkError(msg) from e
 
 
-class ForkError(Exception):
-    pass
-
-
-class GitImporter(Importer):
-    def __init__(self, repo_url):
-        super().__init__()
-        self.repo_url = repo_url
-        self.vcs_response = None
-
-    def __enter__(self):
-        super().__enter__()
-        self.clone()
-        return self
-
-    def __exit__(self):
-        self.vcs_response.delete()
-
-    def clone(self):
-        try:
-            self.vcs_response = fetch_via_vcs(self.repo_url)
-        except Exception as e:
-            msg = f"Failed to fetch {self.repo_url} via vcs: {e}"
-            logger.error(msg)
-            raise ForkError(msg) from e
-
-    def advisory_data(self) -> Iterable[AdvisoryData]:
-        """
-        Return AdvisoryData objects corresponding to the data being imported
-        """
-        raise NotImplementedError
-
-
 # TODO: Needs rewrite
 class OvalImporter(Importer):
     """
@@ -369,6 +390,9 @@ class OvalImporter(Importer):
     `OvalDataSource` class. Subclasses must implement the methods `_fetch` and `set_api`.
     """
 
+    data_url: str = ""
+    importer_name = "Oval Importer"
+
     @staticmethod
     def create_purl(pkg_name: str, pkg_data: Mapping) -> PackageURL:
         """
@@ -440,47 +464,55 @@ class OvalImporter(Importer):
         for definition_data in raw_data:
             # These fields are definition level, i.e common for all elements
             # connected/linked to an OvalDefinition
-            vuln_id = definition_data["vuln_id"]
-            description = definition_data["description"]
 
-            severities = []
-            severity = definition_data.get("severity")
-            if severity:
-                severities.append(
-                    VulnerabilitySeverity(system=severity_systems.GENERIC, value=severity)
+            # NOTE: This is where we loop through the list of CVEs/aliases.
+            vuln_id_list = definition_data["vuln_id"]
+
+            for vuln_id_item in vuln_id_list:
+                vuln_id = vuln_id_item
+                description = definition_data["description"]
+
+                severities = []
+                severity = definition_data.get("severity")
+                if severity:
+                    severities.append(
+                        VulnerabilitySeverity(system=severity_systems.GENERIC, value=severity)
+                    )
+                references = [
+                    Reference(url=url, severities=severities)
+                    for url in definition_data["reference_urls"]
+                ]
+                affected_packages = []
+
+                for test_data in definition_data["test_data"]:
+                    for package_name in test_data["package_list"]:
+                        affected_version_range = test_data["version_ranges"]
+                        vrc = RANGE_CLASS_BY_SCHEMES[pkg_metadata["type"]]
+                        if affected_version_range:
+                            try:
+                                affected_version_range = vrc.from_native(affected_version_range)
+                            except Exception as e:
+                                logger.error(
+                                    f"Failed to parse version range {affected_version_range!r} "
+                                    f"for package {package_name!r}:\n{e}"
+                                )
+                                continue
+                        if package_name:
+                            affected_packages.append(
+                                AffectedPackage(
+                                    package=self.create_purl(package_name, pkg_metadata),
+                                    affected_version_range=affected_version_range,
+                                )
+                            )
+
+                date_published = dateparser.parse(timestamp)
+                if not date_published.tzinfo:
+                    date_published = date_published.replace(tzinfo=pytz.UTC)
+                yield AdvisoryData(
+                    aliases=[vuln_id],
+                    summary=description,
+                    affected_packages=sorted(affected_packages),
+                    references=sorted(references),
+                    date_published=date_published,
+                    url=self.data_url,
                 )
-            references = [
-                Reference(url=url, severities=severities)
-                for url in definition_data["reference_urls"]
-            ]
-            affected_packages = []
-            for test_data in definition_data["test_data"]:
-                for package_name in test_data["package_list"]:
-                    affected_version_range = test_data["version_ranges"]
-                    vrc = RANGE_CLASS_BY_SCHEMES[pkg_metadata["type"]]
-                    if affected_version_range:
-                        try:
-                            affected_version_range = vrc.from_native(affected_version_range)
-                        except Exception as e:
-                            logger.error(
-                                f"Failed to parse version range {affected_version_range!r} "
-                                f"for package {package_name!r}:\n{e}"
-                            )
-                            continue
-                    if package_name:
-                        affected_packages.append(
-                            AffectedPackage(
-                                package=self.create_purl(package_name, pkg_metadata),
-                                affected_version_range=affected_version_range,
-                            )
-                        )
-            date_published = dateparser.parse(timestamp)
-            if not date_published.tzinfo:
-                date_published = date_published.replace(tzinfo=pytz.UTC)
-            yield AdvisoryData(
-                aliases=[vuln_id],
-                summary=description,
-                affected_packages=affected_packages,
-                references=sorted(references),
-                date_published=date_published,
-            )
