@@ -4,7 +4,7 @@
 # VulnerableCode is a trademark of nexB Inc.
 # SPDX-License-Identifier: Apache-2.0
 # See http://www.apache.org/licenses/LICENSE-2.0 for the license text.
-# See https://github.com/nexB/vulnerablecode for support or download.
+# See https://github.com/aboutcode-org/vulnerablecode for support or download.
 # See https://aboutcode.org for more information about nexB OSS projects.
 #
 
@@ -35,6 +35,7 @@ BASE_URL = "https://secdb.alpinelinux.org/"
 class AlpineImporter(Importer):
     spdx_license_expression = "CC-BY-SA-4.0"
     license_url = "https://secdb.alpinelinux.org/license.txt"
+    importer_name = "Alpine Linux Importer"
 
     def advisory_data(self) -> Iterable[AdvisoryData]:
         page_response_content = fetch_response(BASE_URL).content
@@ -50,7 +51,7 @@ class AlpineImporter(Importer):
             if not record["packages"]:
                 LOGGER.error(f'"packages" not found in {link!r}')
                 continue
-            yield from process_record(record)
+            yield from process_record(record=record, url=link)
 
 
 def fetch_advisory_directory_links(page_response_content: str) -> List[str]:
@@ -98,12 +99,12 @@ def check_for_attributes(record) -> bool:
     return True
 
 
-def process_record(record: dict) -> Iterable[AdvisoryData]:
+def process_record(record: dict, url: str) -> Iterable[AdvisoryData]:
     """
     Return a list of AdvisoryData objects by processing data
     present in that `record`
     """
-    if not record["packages"]:
+    if not record.get("packages"):
         LOGGER.error(f'"packages" not found in this record {record!r}')
         return []
 
@@ -114,10 +115,11 @@ def process_record(record: dict) -> Iterable[AdvisoryData]:
         if not check_for_attributes(record):
             continue
         yield from load_advisories(
-            package["pkg"],
-            record["distroversion"],
-            record["reponame"],
-            record["archs"],
+            pkg_infos=package["pkg"],
+            distroversion=record["distroversion"],
+            reponame=record["reponame"],
+            archs=record["archs"],
+            url=url,
         )
 
 
@@ -126,6 +128,7 @@ def load_advisories(
     distroversion: str,
     reponame: str,
     archs: List[str],
+    url: str,
 ) -> Iterable[AdvisoryData]:
     """
     Yield AdvisoryData by mapping data from `pkg_infos`
@@ -211,4 +214,5 @@ def load_advisories(
                 references=references,
                 affected_packages=affected_packages,
                 aliases=aliases,
+                url=url,
             )
