@@ -3,14 +3,16 @@
 # VulnerableCode is a trademark of nexB Inc.
 # SPDX-License-Identifier: Apache-2.0
 # See http://www.apache.org/licenses/LICENSE-2.0 for the license text.
-# See https://github.com/nexB/vulnerablecode for support or download.
+# See https://github.com/aboutcode-org/vulnerablecode for support or download.
 # See https://aboutcode.org for more information about nexB OSS projects.
 #
 
 import dataclasses
+from datetime import datetime
 
 from cvss import CVSS2
 from cvss import CVSS3
+from cvss import CVSS4
 
 """
 Vulnerability scoring systems define scales, values and approach to score a
@@ -37,6 +39,9 @@ class ScoringSystem:
         """
         return NotImplementedError
 
+    def get(self, scoring_elements: str):
+        return NotImplementedError
+
 
 @dataclasses.dataclass(order=True)
 class Cvssv2ScoringSystem(ScoringSystem):
@@ -49,6 +54,10 @@ class Cvssv2ScoringSystem(ScoringSystem):
         """
         return str(CVSS2(vector=scoring_elements).base_score)
 
+    def get(self, scoring_elements: str) -> dict:
+        scoring_elements = scoring_elements.strip()
+        return CVSS2(vector=scoring_elements).as_json()
+
 
 CVSSV2 = Cvssv2ScoringSystem(
     identifier="cvssv2",
@@ -71,6 +80,26 @@ class Cvssv3ScoringSystem(ScoringSystem):
         """
         return str(CVSS3(vector=scoring_elements).base_score)
 
+    def get(self, scoring_elements: str) -> dict:
+        scoring_elements = scoring_elements.strip()
+        return CVSS3(vector=scoring_elements).as_json()
+
+
+@dataclasses.dataclass(order=True)
+class Cvssv4ScoringSystem(ScoringSystem):
+    def compute(self, scoring_elements: str) -> str:
+        """
+        Return a CVSSv4 base score
+
+        >>> CVSSV4.compute('CVSS:4.0/AV:N/AC:L/AT:N/PR:N/UI:N/VC:H/VI:H/VA:H/SC:H/SI:H/SA:N')
+        '9.9'
+        """
+        return str(CVSS4(vector=scoring_elements).base_score)
+
+    def get(self, scoring_elements: str) -> dict:
+        scoring_elements = scoring_elements.strip()
+        return CVSS4(vector=scoring_elements).as_json()
+
 
 CVSSV3 = Cvssv3ScoringSystem(
     identifier="cvssv3",
@@ -86,6 +115,13 @@ CVSSV31 = Cvssv3ScoringSystem(
     notes="CVSSv3.1 base score and vector",
 )
 
+CVSSV4 = Cvssv4ScoringSystem(
+    identifier="cvssv4",
+    name="CVSSv4 Base Score",
+    url="https://www.first.org/cvss/v4-0/",
+    notes="CVSSv4 base score and vector",
+)
+
 REDHAT_BUGZILLA = ScoringSystem(
     identifier="rhbs",
     name="RedHat Bugzilla severity",
@@ -124,6 +160,53 @@ APACHE_HTTPD = ScoringSystem(
     name="Apache Httpd Severity",
     url="https://httpd.apache.org/security/impact_levels.html",
 )
+APACHE_HTTPD.choices = [
+    "Critical",
+    "Important",
+    "Moderate",
+    "Low",
+]
+
+# This is essentially identical to apache_http except for the addition of the "High" score,
+# which seems to be used interchangeably for "Important".
+APACHE_TOMCAT = ScoringSystem(
+    identifier="apache_tomcat",
+    name="Apache Tomcat Severity",
+    url="https://tomcat.apache.org/security-impact.html",
+)
+APACHE_TOMCAT.choices = [
+    "Critical",
+    "High",
+    "Important",
+    "Moderate",
+    "Low",
+]
+
+
+@dataclasses.dataclass(order=True)
+class EPSSScoringSystem(ScoringSystem):
+    def compute(self, scoring_elements: str):
+        return NotImplementedError
+
+
+EPSS = EPSSScoringSystem(
+    identifier="epss",
+    name="Exploit Prediction Scoring System",
+    url="https://www.first.org/epss/",
+)
+
+
+@dataclasses.dataclass(order=True)
+class SSVCScoringSystem(ScoringSystem):
+    def get(self, scoring_elements: str):
+        return {"version": "ssvc", "vectorString": scoring_elements}
+
+
+SSVC = SSVCScoringSystem(
+    identifier="ssvc",
+    name="Stakeholder-Specific Vulnerability Categorization",
+    url="https://www.cisa.gov/stakeholder-specific-vulnerability-categorization-ssvc",
+)
 
 SCORING_SYSTEMS = {
     system.identifier: system
@@ -131,11 +214,15 @@ SCORING_SYSTEMS = {
         CVSSV2,
         CVSSV3,
         CVSSV31,
+        CVSSV4,
         REDHAT_BUGZILLA,
         REDHAT_AGGREGATE,
         ARCHLINUX,
         CVSS31_QUALITY,
         GENERIC,
         APACHE_HTTPD,
+        APACHE_TOMCAT,
+        EPSS,
+        SSVC,
     )
 }
