@@ -3,7 +3,7 @@
 # VulnerableCode is a trademark of nexB Inc.
 # SPDX-License-Identifier: Apache-2.0
 # See http://www.apache.org/licenses/LICENSE-2.0 for the license text.
-# See https://github.com/nexB/vulnerablecode for support or download.
+# See https://github.com/aboutcode-org/vulnerablecode for support or download.
 # See https://aboutcode.org for more information about nexB OSS projects.
 #
 
@@ -35,6 +35,7 @@ ADVISORY_FIELDS_TO_TEST = (
     "affected_packages",
     "references",
     "date_published",
+    "weaknesses",
 )
 
 
@@ -110,6 +111,7 @@ class TestOpenssl(testcase.FileBasedTesting):
                 ),
             ],
             date_published=datetime.datetime(2017, 12, 7, 0, 0, tzinfo=datetime.timezone.utc),
+            url="https://www.openssl.org/news/secadv/20171207.txt",
         )
         issue_parsed = DET.fromstring(issue_string)
         assert expected == openssl.to_advisory_data(issue_parsed)
