@@ -3,7 +3,7 @@
 # VulnerableCode is a trademark of nexB Inc.
 # SPDX-License-Identifier: Apache-2.0
 # See http://www.apache.org/licenses/LICENSE-2.0 for the license text.
-# See https://github.com/nexB/vulnerablecode for support or download.
+# See https://github.com/aboutcode-org/vulnerablecode for support or download.
 # See https://aboutcode.org for more information about nexB OSS projects.
 #
 
@@ -12,6 +12,10 @@ from pathlib import Path
 
 import environ
 
+from vulnerablecode import __version__
+
+VULNERABLECODE_VERSION = __version__
+
 PROJECT_DIR = Path(__file__).resolve().parent
 ROOT_DIR = PROJECT_DIR.parent
 
@@ -30,15 +34,29 @@ SECRET_KEY = env.str("SECRET_KEY")
 
 ALLOWED_HOSTS = env.list("ALLOWED_HOSTS", default=[".localhost", "127.0.0.1", "[::1]"])
 
-# SECURITY WARNING: don't run with debug turned on in production
+VULNERABLECODE_PASSWORD_MIN_LENGTH = env.int("VULNERABLECODE_PASSWORD_MIN_LENGTH", default=14)
+
+CSRF_TRUSTED_ORIGINS = env.list("CSRF_TRUSTED_ORIGINS", default=[])
+
+# SECURITY WARNING: do not run with debug turned on in production
 DEBUG = env.bool("VULNERABLECODE_DEBUG", default=False)
 
-# SECURITY WARNING: don't run with debug turned on in production
+# SECURITY WARNING: do not  run with debug turned on in production
 DEBUG_TOOLBAR = env.bool("VULNERABLECODE_DEBUG_TOOLBAR", default=False)
 
-# SECURITY WARNING: don't run with debug turned on in production
+# SECURITY WARNING: do not  run with debug turned on in production
 DEBUG_UI = env.bool("VULNERABLECODE_DEBUG_UI", default=False)
 
+EMAIL_BACKEND = "django.core.mail.backends.smtp.EmailBackend"
+EMAIL_HOST = env.str("EMAIL_HOST", default="")
+EMAIL_USE_TLS = True
+EMAIL_PORT = 587
+EMAIL_HOST_USER = env.str("EMAIL_HOST_USER", default="")
+EMAIL_HOST_PASSWORD = env.str("EMAIL_HOST_PASSWORD", default="")
+FROM_EMAIL = env.str("FROM_EMAIL", default="")
+
+VULNERABLECODE_LOG_LEVEL = env.str("VULNERABLECODE_LOG_LEVEL", "INFO")
+
 # Application definition
 
 INSTALLED_APPS = (
@@ -54,13 +72,19 @@ INSTALLED_APPS = (
     "django.contrib.admin",
     "django.contrib.humanize",
     # Third-party apps
+    "django_extensions",
     "django_filters",
     "rest_framework",
     "rest_framework.authtoken",
     "widget_tweaks",
+    "crispy_forms",
+    "crispy_bootstrap4",
+    # for API doc
+    "drf_spectacular",
+    # required for Django collectstatic discovery
+    "drf_spectacular_sidecar",
 )
 
-
 MIDDLEWARE = (
     "django.middleware.security.SecurityMiddleware",
     "django.contrib.sessions.middleware.SessionMiddleware",
@@ -69,6 +93,7 @@ MIDDLEWARE = (
     "django.contrib.auth.middleware.AuthenticationMiddleware",
     "django.contrib.messages.middleware.MessageMiddleware",
     "django.middleware.clickjacking.XFrameOptionsMiddleware",
+    "vulnerabilities.middleware.ban_user_agent.BanUserAgent",
 )
 
 ROOT_URLCONF = "vulnerablecode.urls"
@@ -120,7 +145,7 @@ AUTH_PASSWORD_VALIDATORS = [
     {
         "NAME": "django.contrib.auth.password_validation.MinimumLengthValidator",
         "OPTIONS": {
-            "min_length": 14,
+            "min_length": VULNERABLECODE_PASSWORD_MIN_LENGTH,
         },
     },
     {
@@ -151,8 +176,12 @@ VULNERABLECODEIO_REQUIRE_AUTHENTICATION = env.bool(
 LOGIN_REDIRECT_URL = "/"
 LOGOUT_REDIRECT_URL = "/"
 
+REST_FRAMEWORK_DEFAULT_THROTTLE_RATES = {"anon": "3600/hour", "user": "10800/hour"}
+
 if IS_TESTS:
-    VULNERABLECODEIO_REQUIRE_AUTHENTICATION = True
+    VULNERABLECODEIO_REQUIRE_AUTHENTICATION = False
+    REST_FRAMEWORK_DEFAULT_THROTTLE_RATES = {"anon": "10/day", "user": "20/day"}
+
 
 USE_L10N = True
 
@@ -168,6 +197,10 @@ STATICFILES_DIRS = [
     str(PROJECT_DIR / "static"),
 ]
 
+CRISPY_ALLOWED_TEMPLATE_PACKS = "bootstrap4"
+
+CRISPY_TEMPLATE_PACK = "bootstrap4"
+
 # Third-party apps
 
 # Django restframework
@@ -178,25 +211,95 @@ REST_FRAMEWORK = {
     "DEFAULT_RENDERER_CLASSES": (
         "rest_framework.renderers.JSONRenderer",
         "rest_framework.renderers.BrowsableAPIRenderer",
-        #    "rest_framework.renderers.AdminRenderer",
+        "rest_framework.renderers.AdminRenderer",
     ),
     "DEFAULT_FILTER_BACKENDS": (
         "django_filters.rest_framework.DjangoFilterBackend",
         "rest_framework.filters.SearchFilter",
     ),
+    "DEFAULT_THROTTLE_CLASSES": [
+        "vulnerabilities.throttling.StaffUserRateThrottle",
+        "rest_framework.throttling.AnonRateThrottle",
+        "rest_framework.throttling.UserRateThrottle",
+    ],
+    "DEFAULT_THROTTLE_RATES": REST_FRAMEWORK_DEFAULT_THROTTLE_RATES,
+    "EXCEPTION_HANDLER": "vulnerabilities.throttling.throttled_exception_handler",
     "DEFAULT_PAGINATION_CLASS": "vulnerabilities.pagination.SmallResultSetPagination",
     # Limit the load on the Database returning a small number of records by default. https://github.com/nexB/vulnerablecode/issues/819
     "PAGE_SIZE": 10,
+    # for API docs
+    "DEFAULT_SCHEMA_CLASS": "drf_spectacular.openapi.AutoSchema",
 }
 
+api_doc_intro = """
+<div>
+    <p><strong>VulnerableCode</strong> is open data and free software by
+    <a href="https://github.com/nexB/vulnerablecode"> nexB Inc. and others.</a>
+    </p>
+    <p>The VulnerableCode API exposes these endpoints:</p>
+    <ul>
+        <li>
+            <strong>packages/</strong>: main endpoint to lookup for vulnerable packages.
+        </li>
+        <li>
+            <strong>vulnerabilities/</strong>: secondary endpoint to lookup by vulnerabilities.
+        </li>
+        <li>
+            <strong>alias/</strong>: secondary endpoint to lookup vulnerabilities by aliases (e.g., CVE)
+        </li>
+        <li>
+            <strong>cpes/</strong>: secondary endpoint to lookup vulnerabilities by CPE.
+        </li>
+    </ul>
+</div>
+"""
+
+# for API docs
+SPECTACULAR_SETTINGS = {
+    "TITLE": "VulnerableCode API",
+    "DESCRIPTION": api_doc_intro,
+    "VERSION": VULNERABLECODE_VERSION,
+    "TOS": "/tos/",
+    "CONTACT": {
+        "name": "nexB Inc.",
+        "url": "https://public.vulnerablecode.io",
+        "email": "mailto:info@nexb.com",
+    },
+    "LICENSE": {
+        "name": "Source code: Apache-2.0 | Data: CC-BY-SA-4.0",
+        "url": "https://github.com/nexb/vulnerablecode#license",
+    },
+    "SERVE_INCLUDE_SCHEMA": False,
+    # shorthand to use the sidecar instead
+    "SWAGGER_UI_DIST": "SIDECAR",
+    "SWAGGER_UI_FAVICON_HREF": "/static/images/favicon.ico",
+    # See https://swagger.io/docs/open-source-tools/swagger-ui/usage/configuration/
+    "SWAGGER_UI_SETTINGS": {
+        "deepLinking": True,
+        "displayOperationId": True,
+        "defaultModelsExpandDepth": 1,
+        "displayRequestDuration": True,
+        "docExpansion": "list",
+    },
+    "SORT_OPERATIONS": False,
+    "TAGS_SORTER": False,
+}
+
+
 if not VULNERABLECODEIO_REQUIRE_AUTHENTICATION:
     REST_FRAMEWORK["DEFAULT_PERMISSION_CLASSES"] = ("rest_framework.permissions.AllowAny",)
 
 
 if DEBUG_TOOLBAR:
+    # Uncomment this to get pyinstrument profiles
+    # PYINSTRUMENT_PROFILE_DIR = "profiles"
+
     INSTALLED_APPS += ("debug_toolbar",)
 
-    MIDDLEWARE += ("debug_toolbar.middleware.DebugToolbarMiddleware",)
+    MIDDLEWARE += (
+        "debug_toolbar.middleware.DebugToolbarMiddleware",
+        "pyinstrument.middleware.ProfilerMiddleware",
+    )
 
     DEBUG_TOOLBAR_PANELS = (
         "debug_toolbar.panels.history.HistoryPanel",
@@ -218,3 +321,37 @@ if DEBUG_TOOLBAR:
     INTERNAL_IPS = [
         "127.0.0.1",
     ]
+
+
+LOGGING = {
+    "version": 1,
+    "disable_existing_loggers": False,
+    "formatters": {
+        "simple": {
+            "format": "{levelname} {message}",
+            "style": "{",
+        },
+    },
+    "handlers": {
+        "null": {
+            "class": "logging.NullHandler",
+        },
+        "console": {
+            "class": "logging.StreamHandler",
+            "formatter": "simple",
+        },
+    },
+    "loggers": {
+        "vulnerabilities.pipelines": {
+            "handlers": ["console"],
+            "level": VULNERABLECODE_LOG_LEVEL,
+            "propagate": False,
+        },
+    },
+}
+
+if DEBUG:
+    LOGGING["django"] = {
+        "handlers": ["console"],
+        "level": "ERROR",
+    }
